@@ -1,6 +1,6 @@
-/* $Id: exo-toolbars-view.c 46 2005-01-29 19:10:18Z bmeurer $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2004-2005 os-cillation e.K.
+ * Copyright (c) 2004-2006 os-cillation e.K.
  * Copyright (c) 2003      Marco Pesenti Gritti
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
@@ -32,11 +32,13 @@
 #include <string.h>
 #endif
 
+#include <exo/exo-config.h>
 #include <exo/exo-private.h>
 #include <exo/exo-string.h>
 #include <exo/exo-toolbars-editor.h>
 #include <exo/exo-toolbars-private.h>
 #include <exo/exo-toolbars-view.h>
+#include <exo/exo-alias.h>
 
 
 
@@ -175,12 +177,28 @@ static const GtkTargetEntry dst_targets[] =
   { EXO_TOOLBARS_ITEM_TYPE, GTK_TARGET_SAME_APP, 0 },
 };
 
-static GObjectClass *parent_class;
+static GObjectClass *exo_toolbars_view_parent_class;
 static guint         toolbars_view_signals[LAST_SIGNAL];
 
 
 
-G_DEFINE_TYPE (ExoToolbarsView, exo_toolbars_view, GTK_TYPE_VBOX);
+GType
+exo_toolbars_view_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      type = _exo_g_type_register_simple (GTK_TYPE_VBOX,
+                                          "ExoToolbarsView",
+                                          sizeof (ExoToolbarsViewClass),
+                                          exo_toolbars_view_class_init,
+                                          sizeof (ExoToolbarsView),
+                                          exo_toolbars_view_init);
+    }
+
+  return type;
+}
 
 
 
@@ -194,7 +212,7 @@ exo_toolbars_view_class_init (ExoToolbarsViewClass *klass)
 
   g_type_class_add_private (klass, sizeof (ExoToolbarsViewPrivate));
 
-  parent_class = g_type_class_peek_parent (klass);
+  exo_toolbars_view_parent_class = g_type_class_peek_parent (klass);
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_toolbars_view_finalize;
@@ -215,7 +233,7 @@ exo_toolbars_view_class_init (ExoToolbarsViewClass *klass)
                                                          "Editing",
                                                          "Editing",
                                                          FALSE,
-                                                         G_PARAM_READWRITE));
+                                                         EXO_PARAM_READWRITE));
 
   /**
    * ExoToolbarsView:model:
@@ -231,7 +249,7 @@ exo_toolbars_view_class_init (ExoToolbarsViewClass *klass)
                                                         "Model",
                                                         "Model",
                                                         EXO_TYPE_TOOLBARS_MODEL,
-                                                        G_PARAM_READWRITE));
+                                                        EXO_PARAM_READWRITE));
 
   /**
    * ExoToolbarsView:ui-manager:
@@ -248,14 +266,14 @@ exo_toolbars_view_class_init (ExoToolbarsViewClass *klass)
                                                         "UI Manager",
                                                         "UI Manager",
                                                         GTK_TYPE_UI_MANAGER,
-                                                        G_PARAM_READWRITE));
+                                                        EXO_PARAM_READWRITE));
 
   /**
    * ExoToolbarsView::action-request:
    * @view  : An #ExoToolbarsView.
    **/
   toolbars_view_signals[ACTION_REQUEST] =
-    g_signal_new ("action-request",
+    g_signal_new (I_("action-request"),
                   G_TYPE_FROM_CLASS (gobject_class),
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (ExoToolbarsViewClass, action_request),
@@ -277,7 +295,7 @@ exo_toolbars_view_class_init (ExoToolbarsViewClass *klass)
    * connected a handler to this signal.
    **/
   toolbars_view_signals[CUSTOMIZE] =
-    g_signal_new ("customize",
+    g_signal_new (I_("customize"),
                   G_TYPE_FROM_CLASS (gobject_class),
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (ExoToolbarsViewClass, customize),
@@ -304,7 +322,7 @@ exo_toolbars_view_finalize (GObject *object)
   exo_toolbars_view_set_model (view, NULL);
   exo_toolbars_view_set_ui_manager (view, NULL);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  (*G_OBJECT_CLASS (exo_toolbars_view_parent_class)->finalize) (object);
 }
 
 
@@ -469,8 +487,8 @@ exo_toolbars_view_drag_data_get (GtkWidget        *item,
   const gchar *id;
   gchar       *target;
 
-  type = g_object_get_data (G_OBJECT (item), "type");
-  id = g_object_get_data (G_OBJECT (item), "id");
+  type = g_object_get_data (G_OBJECT (item), I_("type"));
+  id = g_object_get_data (G_OBJECT (item), I_("id"));
 
   if (exo_str_is_equal (id, "separator"))
     target = g_strdup (id);
@@ -478,7 +496,7 @@ exo_toolbars_view_drag_data_get (GtkWidget        *item,
     target = exo_toolbars_model_get_item_data (view->priv->model, type, id);
 
   gtk_selection_data_set (selection_data, selection_data->target,
-                          8, target, strlen (target));
+                          8, (guchar *) target, strlen (target));
 
   g_free (target);
 }
@@ -528,8 +546,8 @@ set_item_drag_source (ExoToolbarsModel  *model,
       g_free (stock_id);
     }
 
-  g_object_set_data_full (G_OBJECT (item), "type", g_strdup (type), g_free);
-  g_object_set_data_full (G_OBJECT (item), "id", g_strdup (id), g_free);
+  g_object_set_data_full (G_OBJECT (item), I_("type"), g_strdup (type), g_free);
+  g_object_set_data_full (G_OBJECT (item), I_("id"), g_strdup (id), g_free);
 }
 
 
@@ -636,7 +654,7 @@ exo_toolbars_view_drag_data_received (GtkWidget         *toolbar,
 
   target = gtk_drag_dest_find_target (toolbar, context, NULL);
   type = exo_toolbars_model_get_item_type (view->priv->model, target);
-  id = exo_toolbars_model_get_item_id (view->priv->model, type, selection_data->data);
+  id = exo_toolbars_model_get_item_id (view->priv->model, type, (const gchar *) selection_data->data);
 
   if (G_UNLIKELY (id == NULL))
     {
@@ -659,7 +677,7 @@ exo_toolbars_view_drag_data_received (GtkWidget         *toolbar,
       item_position = gtk_toolbar_get_drop_index (GTK_TOOLBAR (toolbar), x, y);
       toolbar_position = exo_toolbars_view_get_toolbar_position (view, toolbar);
 
-      if (data_is_separator (selection_data->data))
+      if (data_is_separator ((const gchar *) selection_data->data))
         exo_toolbars_model_add_separator (view->priv->model, toolbar_position, item_position);
       else
         exo_toolbars_model_add_item (view->priv->model, toolbar_position, item_position, id, type);
@@ -682,7 +700,7 @@ toolbar_style_activated (GtkWidget       *menuitem,
 
   if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (menuitem)))
     {
-      style = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menuitem), "exo-toolbar-style"));
+      style = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menuitem), I_("exo-toolbar-style")));
       position = exo_toolbars_view_get_toolbar_position (view, view->priv->selected_toolbar);
 
       if (style == 0)
@@ -747,7 +765,7 @@ exo_toolbars_view_context_menu (GtkWidget       *toolbar,
 
   item = gtk_radio_menu_item_new_with_mnemonic (NULL, _("_Desktop Default"));
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), (style < 0));
-  g_object_set_data (G_OBJECT (item), "exo-toolbar-style", GINT_TO_POINTER (0));
+  g_object_set_data (G_OBJECT (item), I_("exo-toolbar-style"), GINT_TO_POINTER (0));
   g_signal_connect (G_OBJECT (item), "activate",
                     G_CALLBACK (toolbar_style_activated), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
@@ -756,7 +774,7 @@ exo_toolbars_view_context_menu (GtkWidget       *toolbar,
   item = gtk_radio_menu_item_new_with_mnemonic_from_widget (GTK_RADIO_MENU_ITEM (item),
                                                             _("_Icons only"));
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), (style == GTK_TOOLBAR_ICONS));
-  g_object_set_data (G_OBJECT (item), "exo-toolbar-style", GINT_TO_POINTER (GTK_TOOLBAR_ICONS + 1));
+  g_object_set_data (G_OBJECT (item), I_("exo-toolbar-style"), GINT_TO_POINTER (GTK_TOOLBAR_ICONS + 1));
   g_signal_connect (G_OBJECT (item), "activate",
                     G_CALLBACK (toolbar_style_activated), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
@@ -765,7 +783,7 @@ exo_toolbars_view_context_menu (GtkWidget       *toolbar,
   item = gtk_radio_menu_item_new_with_mnemonic_from_widget (GTK_RADIO_MENU_ITEM (item),
                                                             _("_Text only"));
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), (style == GTK_TOOLBAR_TEXT));
-  g_object_set_data (G_OBJECT (item), "exo-toolbar-style", GINT_TO_POINTER (GTK_TOOLBAR_TEXT + 1));
+  g_object_set_data (G_OBJECT (item), I_("exo-toolbar-style"), GINT_TO_POINTER (GTK_TOOLBAR_TEXT + 1));
   g_signal_connect (G_OBJECT (item), "activate",
                     G_CALLBACK (toolbar_style_activated), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
@@ -774,7 +792,7 @@ exo_toolbars_view_context_menu (GtkWidget       *toolbar,
   item = gtk_radio_menu_item_new_with_mnemonic_from_widget (GTK_RADIO_MENU_ITEM (item),
                                                             _("Text for _All Icons"));
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), (style == GTK_TOOLBAR_BOTH));
-  g_object_set_data (G_OBJECT (item), "exo-toolbar-style", GINT_TO_POINTER (GTK_TOOLBAR_BOTH + 1));
+  g_object_set_data (G_OBJECT (item), I_("exo-toolbar-style"), GINT_TO_POINTER (GTK_TOOLBAR_BOTH + 1));
   g_signal_connect (G_OBJECT (item), "activate",
                     G_CALLBACK (toolbar_style_activated), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
@@ -783,7 +801,7 @@ exo_toolbars_view_context_menu (GtkWidget       *toolbar,
   item = gtk_radio_menu_item_new_with_mnemonic_from_widget (GTK_RADIO_MENU_ITEM (item),
                                                             _("Text for I_mportant Icons"));
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), (style == GTK_TOOLBAR_BOTH_HORIZ));
-  g_object_set_data (G_OBJECT (item), "exo-toolbar-style", GINT_TO_POINTER (GTK_TOOLBAR_BOTH_HORIZ + 1));
+  g_object_set_data (G_OBJECT (item), I_("exo-toolbar-style"), GINT_TO_POINTER (GTK_TOOLBAR_BOTH_HORIZ + 1));
   g_signal_connect (G_OBJECT (item), "activate",
                     G_CALLBACK (toolbar_style_activated), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
@@ -1402,3 +1420,8 @@ exo_toolbars_view_set_ui_manager (ExoToolbarsView *view,
       exo_toolbars_view_construct (view);
     }
 }
+
+
+
+#define __EXO_TOOLBARS_VIEW_C__
+#include <exo/exo-aliasdef.c>
